@@ -8,13 +8,12 @@ import (
 	"github.com/olekukonko/tablewriter"
 	"github.com/spf13/cobra"
 
-	"github.com/superfly/flyctl/client"
+	fly "github.com/superfly/fly-go"
 	"github.com/superfly/flyctl/flyctl"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/command/agent"
 	"github.com/superfly/flyctl/internal/command/apps"
 	"github.com/superfly/flyctl/internal/command/auth"
-	"github.com/superfly/flyctl/internal/command/autoscale"
 	"github.com/superfly/flyctl/internal/command/certificates"
 	"github.com/superfly/flyctl/internal/command/checks"
 	"github.com/superfly/flyctl/internal/command/config"
@@ -41,8 +40,6 @@ import (
 	"github.com/superfly/flyctl/internal/command/logs"
 	"github.com/superfly/flyctl/internal/command/machine"
 	"github.com/superfly/flyctl/internal/command/metrics"
-	"github.com/superfly/flyctl/internal/command/migrate_to_v2"
-	"github.com/superfly/flyctl/internal/command/monitor"
 	"github.com/superfly/flyctl/internal/command/move"
 	"github.com/superfly/flyctl/internal/command/mysql"
 	"github.com/superfly/flyctl/internal/command/open"
@@ -64,9 +61,7 @@ import (
 	"github.com/superfly/flyctl/internal/command/storage"
 	"github.com/superfly/flyctl/internal/command/suspend"
 	"github.com/superfly/flyctl/internal/command/tokens"
-	"github.com/superfly/flyctl/internal/command/turboku"
 	"github.com/superfly/flyctl/internal/command/version"
-	"github.com/superfly/flyctl/internal/command/vm"
 	"github.com/superfly/flyctl/internal/command/volumes"
 	"github.com/superfly/flyctl/internal/command/wireguard"
 	"github.com/superfly/flyctl/internal/flag/flagnames"
@@ -123,7 +118,6 @@ func New() *cobra.Command {
 		group(launch.New(), "deploy"),
 		group(info.New(), "upkeep"),
 		jobs.New(),
-		turboku.New(),
 		group(services.New(), "upkeep"),
 		group(config.New(), "configuring"),
 		group(scale.New(), "configuring"),
@@ -148,11 +142,7 @@ func New() *cobra.Command {
 		resume.New(),     // TODO: deprecate
 		dnsrecords.New(), // TODO: deprecate
 
-		monitor.New(),       // TODO: deprecate
-		vm.New(),            // TODO: deprecate
-		migrate_to_v2.New(), // TODO: deprecate
-		regions.New(),       // TODO: deprecate
-		autoscale.New(),     // TODO: deprecate
+		regions.New(), // TODO: deprecate
 	)
 
 	// if os.Getenv("DEV") != "" {
@@ -200,7 +190,7 @@ func run(ctx context.Context) error {
 	cmd.Printf("  %s\n", "flyctl [command]")
 	cmd.Println()
 
-	if !client.FromContext(ctx).Authenticated() {
+	if !fly.ClientFromContext(ctx).Authenticated() {
 		msg := `It doesn't look like you're logged in. Try "fly auth signup" to create an account, or "fly auth login" to log in to an existing account.`
 		cmd.Println(text.Wrap(msg, 80))
 		cmd.Println()
